// Copyright 2017-2025 WIT.COM Inc. All rights reserved.
// Use of this source code is governed by the GPL 3.0

package main

/*
	this parses the command line arguements
	this enables command line options from other packages like 'gui' and 'log'
*/

import (
	"go.wit.com/dev/alexflint/arg"
	"go.wit.com/log"
)

var argv args

type args struct {
	Daemon bool `arg:"--daemon"           default:"false"  help:"run in daemon mode"`
	Port   int  `arg:"--port"             default:"8080"   help:"port to run on"`
}

func (args) Version() string {
	return "zood " + VERSION + "   Built on: " + BUILDTIME
}

func init() {
	arg.MustParse(&argv)
}

func (a args) Description() string {
	return `
         this daemon talks to zookeeper
`
}

var NOW *log.LogFlag
var INFO *log.LogFlag
var ZOOD *log.LogFlag
var WARN *log.LogFlag

func init() {
	full := "go.wit.com/apps/zookeeper"
	short := "zookeeper"

	NOW = log.NewFlag("NOW", true, full, short, "useful while doing debugging")
	INFO = log.NewFlag("INFO", false, full, short, "general zookeeper")
	ZOOD = log.NewFlag("ZOOD", false, full, short, "show reporting from zood")
	WARN = log.NewFlag("WARN", true, full, short, "bad things")
}
